#ifndef LIGHT_H
#define LIGHT_H

// Provides a name for each of the lights that the circuit drives.
enum light {
	LIGHT_A = 0,
	LIGHT_B = 1,
	LIGHT_C = 2,
	LIGHT_D = 3,
};

// Defines the DDR, bit and OC register for each light.
#define LIGHT_A_DDR (DDRB)
#define LIGHT_A_BIT (2)
#define LIGHT_A_OC (OCR0A)

#define LIGHT_B_DDR (DDRD)
#define LIGHT_B_BIT (5)
#define LIGHT_B_OC (OCR0B)

#define LIGHT_C_DDR (DDRB)
#define LIGHT_C_BIT (3)
#define LIGHT_C_OC (OCR1A)

#define LIGHT_D_DDR (DDRB)
#define LIGHT_D_BIT (4)
#define LIGHT_D_OC (OCR1B)

// Initialise the lights. Interrupts should be enabled afterwards.
void light_init(void);

// Sets the brightness of a single light.
void light_set_level(enum light light, uint8_t level);

// Update lights A and B in response to a timer interrupt.
void light_timer_update_ab(void);

// Update lights C and D in response to a timer interrupt.
void light_timer_update_cd(void);

#endif